#
# spec file for package gtk-vnc
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sover -2_0-0
%define _sonamever 2.0
%define _sonamepkg 2_0

Name:           gtk-vnc
Version:        1.3.1
Release:        1.9
Summary:        A GTK widget for VNC clients
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          Development/Libraries/X11
URL:            https://wiki.gnome.org/Projects/gtk-vnc
Source0:        https://download.gnome.org/sources/gtk-vnc/1.3/%{name}-%{version}.tar.xz

BuildRequires:  cyrus-sasl-devel
BuildRequires:  gobject-introspection-devel >= 0.9.4
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel >= 1.5.0
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gnutls) >= 3.1.18
BuildRequires:  pkgconfig(gobject-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libpulse-simple)

%description
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

%package -n libgvnc-1_0-0
Summary:        GObject-based library to interact with the RFB protocol
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          Development/Libraries/X11

%description  -n libgvnc-1_0-0
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

This package contains the GObject-based library to interact with the
RFB protocol.

%package -n typelib-1_0-GVnc-1_0
Summary:        Introspection bindings for gtk-vnc
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-GVnc-1_0
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

This package provides the GObject Introspection bindings for the libgvnc
library.

%package -n libgvncpulse-1_0-0
Summary:        Pulse audio bridge for VNC client connections
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          Development/Libraries/X11

%description  -n libgvncpulse-1_0-0
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

This package contains the Pulse audio bridge for VNC client connections.

%package -n typelib-1_0-GVncPulse-1_0
Summary:        Pulse audio bridge for VNC client connections -- Introspection bindings
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-GVncPulse-1_0
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

This package provides the GObject Introspection bindings for the
libgvncpulse library.

%package -n libgtk-vnc%{_sover}
Summary:        A GTK widget for VNC clients
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          Development/Libraries/X11
# Needed to make lang package installable (and because we used to
# have a gtk-vnc package earlier).
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description  -n libgtk-vnc%{_sover}
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

%package -n typelib-1_0-GtkVnc-%{_sonamepkg}
Summary:        A GTK widget for VNC clients -- Introspection bindings
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-GtkVnc-%{_sonamepkg}
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

This package provides the GObject Introspection bindings for the
libgtk-vnc library.

%package tools
Summary:        VNC Tools based on gtk-vnc
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11

%description tools
This package contains tools based on gtk-vnc:

 - gvnccapture: a tool to capture a screenshot of the VNC desktop

 - gvncviewer: a simple VNC client

%package devel
Summary:        A GTK widget for VNC clients -- Development Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11
Requires:       libgtk-vnc%{_sover} = %{version}
Requires:       libgvnc-1_0-0 = %{version}
Requires:       libgvncpulse-1_0-0 = %{version}
Requires:       typelib-1_0-GVnc-1_0 = %{version}
Requires:       typelib-1_0-GVncPulse-1_0 = %{version}
Requires:       typelib-1_0-GtkVnc-%{_sonamepkg} = %{version}

%description devel
gtk-vnc is a VNC viewer widget for GTK+. It is built using coroutines
allowing it to be completely asynchronous while remaining single
threaded.

%lang_package

%prep
%autosetup
# install gvncviewer
sed -i '/install:/s/false/true/' examples/meson.build

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%check
%meson_test

%post    -n libgvnc-1_0-0 -p /sbin/ldconfig
%postun  -n libgvnc-1_0-0 -p /sbin/ldconfig

%post    -n libgvncpulse-1_0-0 -p /sbin/ldconfig
%postun  -n libgvncpulse-1_0-0 -p /sbin/ldconfig

%post    -n libgtk-vnc%{_sover} -p /sbin/ldconfig
%postun  -n libgtk-vnc%{_sover} -p /sbin/ldconfig

%files -n libgvnc-1_0-0
%license COPYING.LIB
%{_libdir}/libgvnc-1.0.so.0*

%files -n typelib-1_0-GVnc-1_0
%{_libdir}/girepository-1.0/GVnc-1.0.typelib

%files -n libgvncpulse-1_0-0
%license COPYING.LIB
%{_libdir}/libgvncpulse-1.0.so.0*

%files -n typelib-1_0-GVncPulse-1_0
%{_libdir}/girepository-1.0/GVncPulse-1.0.typelib

%files -n libgtk-vnc%{_sover}
%license COPYING.LIB
%doc NEWS README
%{_libdir}/libgtk-vnc-%{_sonamever}.so.0*

%files -n typelib-1_0-GtkVnc-%{_sonamepkg}
%{_libdir}/girepository-1.0/GtkVnc-%{_sonamever}.typelib

%files tools
%{_bindir}/gvnccapture
%{_bindir}/gvncviewer
%{_mandir}/man1/gvnccapture.1%{?ext_man}

%files devel
%doc AUTHORS ChangeLog
%{_includedir}/gvnc-1.0/
%{_includedir}/gvncpulse-1.0/
%{_libdir}/libgvnc-1.0.so
%{_libdir}/libgvncpulse-1.0.so
%{_libdir}/pkgconfig/gvnc-1.0.pc
%{_libdir}/pkgconfig/gvncpulse-1.0.pc
%{_datadir}/gir-1.0/GVnc-1.0.gir
%{_datadir}/gir-1.0/GVncPulse-1.0.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gtk-vnc-%{_sonamever}.deps
%{_datadir}/vala/vapi/gtk-vnc-%{_sonamever}.vapi
%{_datadir}/vala/vapi/gvnc-1.0.deps
%{_datadir}/vala/vapi/gvnc-1.0.vapi
%{_datadir}/vala/vapi/gvncpulse-1.0.deps
%{_datadir}/vala/vapi/gvncpulse-1.0.vapi
%{_includedir}/gtk-vnc-%{_sonamever}/
%{_libdir}/libgtk-vnc-%{_sonamever}.so
%{_libdir}/pkgconfig/gtk-vnc-%{_sonamever}.pc
%{_datadir}/gir-1.0/GtkVnc-%{_sonamever}.gir

%files lang -f %{name}.lang

%changelog
* Fri Aug  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.3.1:
  + Fix invalid use of subprojects with meson.
  + Support ZRLE encoding for zero size alpha cursors.
  + Add 'check' arg to meson run_command().
* Wed Nov 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.3.0:
  + Add API to request screen rotation.
  + Automatically pick gthread coroutine if ucontext is not
    available.
  + Fix meson logic bug when disabling vala.
  + Honour choice of python when generating keymaps.
  + Fix error reporting and memory leaks encrypting auth data.
  + Fix missing includes for GDK quartz and broadway backends.
  + Switch to GNUTLS for VNC auth challenge to fix empty password
    handling.
  + Fix handling of auth subtypes in gvnccapture program.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.0:
  + Add API to request fixed zoom level.
  + Add API to request fixed aspect ratio when scaling.
  + Add APIs for client initiated desktop resize.
  + Implement "Extended Desktop Resize" VNC extension.
  + Implement "Desktop Rename" VNC extension.
  + Implement "Last Rect" VNC extension.
  + Implement "XVP" (power control) VNC extension.
  + Implement VeNCrypt "plain" auth mode.
  + Implement alpha cursor VNC extension.
  + Fix JPEG decoding in low colour depth modes.
  + Update translations.
* Sat Mar 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(gvnc-1.0) BuildRequires: Package builds fine
  without buildrequiring itself, but complains somewhat loudly.
- Add check section and meson_test macro, run tests during build.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Aug  9 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.0:
  + Autotools build system replaced with meson.
  + Support for GTK-2 is dropped. GTK-3 is mandatory.
  + Support for libview is dropped in example program.
  + Improvements to example demos.
  + Use MAP_ANON if MAP_ANONYMOUS doesn't exist to help certain
    macOS versions.
  + Fix crash when connection attempt fails early.
  + Initialize gcrypt early in auth process.
  + Emit vnc-auth-failure signal when SASL auth fails.
  + Emit vnc-error signal when authentication fails.
  + Fix double free when failing to read certificates.
  + Run unit tests in RPM build.
  + Modernize RPM spec.
  + Fix race condition in unit tests.
  + Fix install of missing header for cairo framebuffer.
  + Fix typo in gir package name.
  + Add missing VncPixelFormat file to git data.
- Add meson BuildRequires and macros.
- Drop libtool BuildRequires: No longer needed.
- Drop translation-update-upstream BuildRequires and macro, SUSE no
  longer provides extra translations for gtk-vnc.
- Replace gtk3-devel with pkgconfig(gtk+-3.0) BuildRequires: Align
  with what meson checks for.
- Add pkgconfig(gvnc-1.0) BuildRequires: New dependency.
- Use sed hack to enable install of gncviewer.
* Thu Sep 27 2018 luc14n0@linuxmail.org
- Add gio-2.0, gio-unix-2.0 and gobject-2.0 pkgconfig modules
  BuildRequires to main pakage to avoid implicit dependencies.
* Sat Aug 18 2018 bjorn.lie@gmail.com
- Update to version 0.9.0:
  + Use libgcrypt for DES routines
  + Add missing cipher close calls in ARD auth
  + Check for errors after reading mslogon params
  + Support newer UltraVNC mslogon auth type code
  + Avoid divide by zero in mslogin auth from bogus params
  + Re-allow python2 accidentally blocked when removing python
    binding.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 0.8.0:
  + Deleted the python2 binding in favour of GObject introspection.
  + Pull in latest keycodemapdb content.
  + Disable/fix -Wcast-function-type warnings.
- Drop gtk-vnc2 linked package and all it's subpackages and
  conditionals, no longer supported upstream.
* Sun Mar 25 2018 luc14n0@linuxmail.org
- Update to version 0.7.2:
  + Deprecated the manual python2 binding in favour of GObject
    introspection. It will be deleted in the next release.
  + Emit led state notification on connect.
  + Fix incorrect copyright notices.
  + Simplify shifted-tab key handling.
  + Don't short circuit TLS credential request.
  + Improve check for keymap under XWayland.
- Update:
  + URL tag to https://wiki.gnome.org/Projects/gtk-vnc: currently
    the gtk-vnc's web page.
  + '+' in LGPL License tags to '-or-later' to comply with SPDX
    3.0.
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 0.7.1:
  + Explicitly link to GIO instead of relying on implicit linkage.
  + Switch to use new keycodemap database module.
  + Fix size of reserved data in class struct.
  + Fix inverted framebuffer args in test case.
  + Avoid sign extension in integer arithmetic.
  + Avoid crash when opening a GSocketAddress.
  + Fix crash if server connection times out.
  + Fix incompatibility with libvncserver.
- Drop obsolete FIXME about browser plugin, dropped upstream back
  in 2013.
* Sat Feb 18 2017 zaitor@opensuse.org
- Update License to include LGPL-2.1.
* Thu Feb  9 2017 badshah400@gmail.com
- Update to version 0.7.0:
  + CVE-2017-5884 - fix bounds checking for RRE, hextile and
    copyrect encodings (bsc#1024266).
  + CVE-2017-5885 - fix color map index bounds checking
    (bsc#1024268).
  + Add API to allow smooth scaling to be disabled.
  + Workaround to help SPICE servers quickly drop VNC clients
    which mistakenly connect, by sending "RFB " signature bytes
    early.
  + Don't accept color map entries for true-color pixel formats.
  + Add missing vala .deps files for gvnc & gvncpulse.
  + Avoid crash if host/port is NULL.
  + Add precondition checks to some public APIs.
  + Fix link to home page in README file.
  + Fix misc memory leaks.
  + Clamp cursor hot-pixel to within cursor region.
- Update file list for %%{name}-devel to include additional files
  installed by updated version.
* Thu Aug 18 2016 zaitor@opensuse.org
- Update to version 0.6.0:
  + Important changes:
  - Default to build with GTK-3, use --with-gtk=2.0 to override.
  + New features:
  - Add --with-tls-priority configure flag to set default TLS
    priority string.
  - Add a 'vnc-error' signal to report reason for disconnect.
  - Add support for fallback to GNUTLS system trust DB.
  + Bug fixes:
  - Fix crash on Windows with GTK3 checking realized state.
  - Fix XKB detection of keyboard mapping with Xwayland.
  - Switch back to XKB detection for Xwayland.
  - Remove duplicate cert expiry check.
  - Avoid misc compile warnings.
  - Add missing API docs + GObject introspection annotations.
  - Add missing GIO dep on gvnc library GObject introspection
    build.
  - Remove unused code.
  - Fix redraw on Win10.
  - Drop support for gnutls < 2.2.0.
  - Fix path to h2def script.
  - Update compiler warning detection to fix clang build.
  - Ignore cast align warnings to fix clang build.
  - Fix endianess inversion when setting pixel format.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop gtk-vnc-Enable-double-buffering-on-GTK3.patch: fixed
  upstream.
* Tue Feb 10 2015 dimstar@opensuse.org
- Update to version 0.5.4:
  + Fix auth when using PLAIN SASL method.
  + Fix introspection build support on FreeBSD.
  + Remove use of deprecated GTK_STOCK_* constants.
  + Fix parallel build for introspection files.
  + Add mising dep on Gtk introspection file.
  + Release held keys when getting grab notify.
  + Don't call into GDK if no GdkWindow is realized.
  + Chain up parent realize_event vfunc.
  + Fix colourmap mode by always sending pixel format message.
  + Update GCC compiler warning flags used.
  + Enable double buffering on Gtk3 to fix child widget clipping.
  + Disable -Wbad-function-cast to avoid glib header warnings.
  + Don't set thread callbacks on gcrypt >= 1.6 or gnutls >= 2.12.
  + Do explicit check for gcrypt since gnutls might use nettle.
  + Add support for Wayland & Xwayland keymaps.
  + Add support for Gtk Broadway backend keymaps.
  + Fix AltGr handling on Windows displays.
  + Fix virtual keycode conversion on Win32.
  + Fix USB/HID scsancodes for volume keys.
  + Updated translations.
* Mon Feb  2 2015 fezhang@suse.com
- Add gtk-vnc-Enable-double-buffering-on-GTK3.patch to fix the
  toolbar displaying problem. (boo#890568)
* Wed Sep 25 2013 dimstar@opensuse.org
- Do not package translations when building for gtk2: the
  translation files do not depend on the toolkit used.
- Always recommend gtk-vnc-lang (%%{_name}-lang) instead of
  gtk-vnc(2)?-lang.
* Wed Sep 18 2013 dimstar@opensuse.org
- Update to version 0.5.3:
  + Support QEMU LED state extension.
  + Bugs fixed:
  - Time out connection attempt after 10 seconds.
  - Abort if out of memory when mmap'ing coroutine stack.
  - Stop leaking coroutine stack memory.
  - Improve perfornmance of ZRLE encoding by avoiding memmove.
  - Only trigger keyboard grab sequence upon key release to
    allow modifiers to go to the remote server.
  - Avoid busy loop upon I/O error which follows blocking I/O,
    commonly seen when a server drops the connection.
  - Fix handling of --no-undefined flag.
  - Don't break implicit pointer grab from mouse clicks.
  - Don't drop mouse events that are out of bounds, clamp their
    coordinates instead.
  - Show how to block all accelerators in gvncviewer demo
    program.
* Fri Mar 22 2013 cfarrell@suse.com
- license update: LGPL-2.1+
  Consolidate licenses
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 0.5.2:
  + Browser plugin is deleted, since it was unmaintained.
  + Bugs fixed:
  - Misc fixes to RPM specfiles
  - Fix big-endian support in cairo framebuffer
  - Avoid out of bounds accessing arrays
  - Fix win32 quote key mapping
  - Fix NULL dereference in logging code
  - Fix OOM check in python bindings
  - Avoid array overrun in colourmap mode
  - Fix buffer space check when sending data
  - Add introspection annotation for vnc_display_send_keys
  - Fix pulseaudio enablement in demo
  - Avoid crash with unsupported audio formats
  - Turn off deprecation warnings
  - Convert VncConnectionCredential to VncDisplayCredential
  - Add API to allow access to keysyms from introspected bindings
  + Updated translations.
* Sun Jul 15 2012 zaitor@opensuse.org
- Update to version 0.5.1:
  + New features:
  - New API for connecting to a GSocketAddress * object
  - New API to allow specification of a hostname with a
    pre-opened file descriptor
  - Support for UNIX domain sockets in gvncviewer demo
  - Updated translations
  + Bug fixes:
  - Fix building with newer glibc-headers and -O0
  - Fix GIR building by linking against libgvnc from builddir
  - Fix deprecation warnings when building against glib >= 2.32
  - Switch to using mingw64 toolchain for Win32 builds
  - Fix introspection of key grab APIs
  - Ensure debugging works with GLib >= 2.32
  - Allow explicit control over pulseaudio building
  - Add check for Perl  Text::CSV when building from GIT
  - Fix POD syntax in gvnccapture man page
  - Reduce excessive stack usage in vncconnection.c
- Drop gtk-vnc-glib231-debug.patch, fixed upstream.
* Mon Jul  2 2012 dimstar@opensuse.org
- Add gtk-vnc-glib231-debug.patch: Ensure debugging works on
  GLib >= 2.32. Without this, it will be difficult to do any
  debugging work in case of issues (gvncviewer --gtk-vnc-debug).
* Wed May 23 2012 vuntz@opensuse.org
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Mon May 21 2012 badshah400@gmail.com
- Use pkgconfig(gnutls) BuildRequires instead of gnutls-devel. This
  is more correct and helps avoid the issue with gnutls-devel
  having been removed from Factory.
* Thu Dec 22 2011 vuntz@opensuse.org
- Update to version 0.5.0:
  + New features:
  - QEMU audio extension support
  + Bug fixes:
  - Avoid deprecated GNUTLS functions
  - Allow access to VncConnection object inside VncDisplay
  - Don't override PKG_CONFIG_PATH when building GIR files
  - Death to all TABs
  - General code style/indentation cleanup
  - Fix memory leak in keymap code
  - Fix mapping of shift key in Windows
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add pkgconfig(libpulse-simple) BuildRequires: new upstream
  dependency, for the QEMU audio extension support.
- Create libgvncpulse-1_0-0 and typelib-1_0-GVncPulse-1_0
  subpackages for the new libgvncpulse library. We only build them
  for the gtk3 build (so we remove the files in %%install for the
  gtk2 build).
- Add the new libgvncpulse-1_0-0 and typelib-1_0-GVncPulse-1_0
  subpackages as Requires to the devel subpackage.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib into their own subpackages: typelib-1_0-GVnc-1_0
  and typelib-1_0-GtkVnc-(1.0|2.0).
- Add typelib-1_0-GVnc-1_0 and typelib-1_0-GtkVnc-(1.0|2.0)
  Requires to devel subpackage.
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.4.4:
  + New feature: vala bindings
  + Bug fixes:
  - Missing OS-X keymapping for the letter 'A'
  - Mapping for Left Control / Alt keys
  - Fix leak of string list in grab sequence string
  - Fix introspection for vnc_display_get_pixbuf
  - Fix GTK3 build on Mingw32
  - Improved log messages for TLS auth subtypes
  + Updated translations.
- Add vala BuildRequires for the new vala bindings when building
  for gtk3.
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Aug 24 2011 crrodriguez@opensuse.org
- Add libgcrypt-devel BuildRequires. This used to be pulled in by
  gnutls-devel, but this is no longer the case.
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 0.4.3:
  + Bug fixes:
  - Fix crash in pointer motion event handler
  - Fix crash in vnc_display_get_pixbuf
  - Fix crash in TLS cleanup code
  - Fix framebuffer boundary checks
  - Improve drawing performance with server side pixmap
  - Fix performance degradation due to leaked GSource
  - Fix setting of 'shared' connection flag
  - Make pointer warp boundary detection more robust
  - Adapt keymap code to build with GDK3 multiple displays
  - Remove use of gdk_drawable calls to fix GTK3
  + Code cleanup:
  - Remove need for Text::CSV perl module at build time
- Add pre_checkin.sh to build gtk2 and gtk3 version of the package
  and add some macros to handle dual gtk2 / gtk3 packages.
- Differences between gtk2 / gtk3 packages:
  + gtk3 package doesn't come with python bindings as introspection
    support is used instead.
  + Pass --with-gtk=2.0/--with-gtk=3.0 to configure as appropriate.
  + libgvnc-1_0-0 and tools subpackages are only kept for gtk3
    build.
- Drop gtk-vnc-unref-gsource.patch: fixed upstream.
- Use Recommends instead of Requires for the -lang package.
- Remove explicit gtk2-devel Requires from the -devel package: the
  right Requires will automatically be added the pkgconfig() way.
- Drop perl-Text-CSV BuildRequires.
* Tue Feb 15 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Feb 15 2011 rhafer@suse.de
- Add gtk-vnc-unref-gsource.patch to fix cpu usage and speed
  problems in virt-manager (bnc#672071, rh#657847)
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 0.4.2:
  + New features:
  - OSX VNC Authentication scheme
  - Add API to query library version
  + Bug fixes
  + Switched over to GIO for socket connections.
  + Removed all use of GNULIB. GIO now handles all portability
    issues with sockets.
  + Mandate use of cairo for all drawing, removing any use of
    GdkPixmap, GdkImage and GdkBitmap.
  + Updated translations.
- Drop gtk-vnc-0.4.1-close-buffer.patch: fixed upstream.
- Add perl-Text-CSV BuildRequires for keymap-gen.pl to work.
* Mon Sep 27 2010 seife@opensuse.org
- Add gtk-vnc-0.4.1-close-buffer.patch to fix virt-manager crashes
  (bnc#641981, rh#620843).
* Mon Aug  9 2010 vuntz@opensuse.org
- Build introspection support: add gobject-introspection-devel
  BuildRequires.
- Remove gtkglext-devel BuildRequires and replace gnome-common
  BuildRequires with intltool.
- Split the libgvnc library in its own libgvnc-1_0-0 subpackage.
- Move %%py_requires to python-gtk-vnc subpackage.
- Pass --with-examples to configure to build the gvncviewer tool.
- Package examples/gvncviewer.py in python-gtk-vnc as
  documentation.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.4.1:
  + Fix test suite execution
  + Ensure builds against GTK3 get a separate library soname,
    pkg-config file and include directory to allow parallel
    install with GTK2 builds
- Changes from version 0.4.0:
  + Refactored gvnc module to provide a full GObject for
    interacting with the RFB protcol.
  + Create a libgvnc.so for non-GTK related APIs for dealing with
    RFB protcol
  + Add gvnccapture command line tool for screenshot capture
  + Fix protocol greeting so wireshark detects stream
  + Fix build with GSEAL
  + Try next DNS address after any connect failure
  + Plugin build with newer mozilla
  + Fix linkage to libgpg-error
  + Fix linker flags on solaris
  + Fix gcrypt threading callbacks
  + Fix multiple memory leaks
  + Remove use of PATH_MAX to fix Hurd
- Drop gtk-vnc-0.3.3-pkgconfig.patch, upstream fixed.
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 0.3.10:
  + Bug fixes:
  - Fix check for SASL on Solaris
  - Improvements on autoconf stuff such as drop some warnings,
    use silent Makefile rules, etc.
  - Improvements on the example program
  - Request a full screen update when receives a desktop-resize
    encoding
  + New features:
  - Add internationalization (i18n) support
  - Add ability to set the depth color
  - Add ability to request a full screen update
  + Updated translations.
- Create a lang package.
* Tue Aug 11 2009 vuntz@novell.com
- Update to version 0.3.9:
  + Bug fixes:
  - Fix Shift+Tab keyval translation (again)
  - Remove use of deprecated GTK+ symbols
  - Fix inverted logic for release pointer grab
  - Fix enter/leave event handling in relative mouse mode
  - Don't send keys/clipboard data in readonly mode
  - Fix relative mouse motion mode edge tracing
  - Fix linking to libgcrypt for mingw32 platform
  + New features:
  - Add API to get command line GOptionEntry objects
  - Support SASL authentication extension
  - Support MS Logon authentication extension
- Add cyrus-sasl-devel BuildRequires.
* Thu Mar 19 2009 vuntz@novell.com
- Do not create a gtk-vnc package with only documentation, and
  instead ship the documentation in the libgtk-vnc-1_0-0 package
  (add Obsoletes/Provides for this)
- Remove AutoReqProv: it's default now.
- Remove check for old version of openSUSE.
- Remove unneeded BuildRequires: perl-XML-Parser.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.3.8:
  + Fix threads based coroutine locking
  + Switch to alternate d3des code for clarity in
    licensing terms
  + Re-write keycode handling to improve correctness on
    non-US keyboard layouts
  + Fix keycode to scancode translation for evdev keyboard
    driver
  + Save dimensions when getting desktop resize events
  + Avoid bogus framebuffer updates from psuedo-encodings
  + Always allow key ungrab if keyboard grab is active
  + Use Cairo for scaling support instead of OpenGL
  + Ported to compile & run under Win32/MinGW
- Removed gtk-vnc-0.3.7-ungrab.patch. Fixed upstream
* Tue Nov 25 2008 anschneider@suse.de
- Fix for inability to ungrab mouse when in absolute pointer mode
* Mon Sep 15 2008 jpr@novell.com
- Enable scaling support
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.3.7:
  + Ungrab pointer if widget loses focus
  + Set a pixmap format if server does not default to true colour
    mode
  + Misc fixes to prevent crash
  + Register internal signal handlers against class instead
    of per object
  + New feature: Add API to allow down-scaling to be enabled.
* Thu Aug 14 2008 crrodriguez@suse.de
- pkgconfig has an odd behaviour with "Requires.private"
* Mon Jun 23 2008 maw@suse.de
- Update to version 0.3.6:
  + Focus widget on mouse click
  + WMVi support
  + OpenGL based scaling
  + VNC scancode extension
  + Use glib for debugging and always enable it
  + GObject properties
  + Accessor to determine if we're in absolute mode
  + Provide interface to control shared flag
  + Support preferred authentication types
  + Many bug fixes; see the package's NEWS file for a fuller
    account.
* Fri Jun 13 2008 crrodriguez@suse.de
- disable unusable static libraries
* Tue Feb 19 2008 maw@suse.de
- Update to version 0.3.3:
  + Bug fixes:
  * Track keystates to reset keyboard state on focus out
  * Fix SEGV in vnc_display_close
  * Compiler fixes for suncc
  * More UltraVNC compatibility
  * Big endian fixes
  * Hide password characters in gvncviewer
  * More debug on protocol error
  * Fix SEGV on coroutine free
  * Fix ZRLE encoding
  + New features:
  * Support got Tight encoding
  * Mozilla browser plugin
  * Output configure summary.
* Thu Jan 17 2008 jpr@suse.de
- Update to 0.3.2
  * fix a bug in the python bindings whereas send_keys() was not
    always returning a value.
  * fix a bug in how mouse events get propagated and ensures that
    the right number of encodings are sent to the server.
  * fix RichCursor encoding when the server is using a depth of
    less than 24.
  * fix solaris build issues
  * fix cursor grabbing
  * fix race during connect()
  * fix SELinux error
  * fix race in coroutine library
  * new interface was added (vnc_display_send_keys_ex) for passing
    key press and key release sequences directly and for sending
    pointer events directly (vnc_display_send_pointer).
  * new interface was added (vnc_display_set_read_only) to prevent
    the user from being able to send any input at all to the server.
  * support for the RRE encoding was added along with a GThread-based
    coroutine implementation to improve portability.
  * ZRLE support added
  * Interfaces for bell messages and the clipboard are now
    supported.
  * RFB 3.4 is now supported for increased compatibility with
    UltraVNC.
- Adhere to shlib policy
- Remove gtk-vnc-0.2.0-coroutine-caller.patch,
  gtk-vnc-0.2.0-execmem.patch and
  gtk-vnc-0.2.0-coroutine-cleanup.patch, they are now included
  upstream
* Tue Oct 23 2007 bk@suse.de
- packaged for virt-manager, based on gtk-vnc-0.2.0-4.fc8.src.rpm
